@@ -18,7 +18,7 @@ use POSIX;
 use Scalar::Util qw(blessed);
 use Time::HiRes qw(gettimeofday tv_interval);
 
-our $VERSION = '0.23'; # VERSION
+our $VERSION = '0.24'; # VERSION
 
 sub prepare_app {
     my $self = shift;
@@ -139,15 +139,15 @@ sub log_access {
         "\n"
     );
 
-    my $uri = $rreq->{uri};
+    my $uri = $rreq->{uri} // "-";
     my $log_line = sprintf(
         $fmt,
         $time,
         $env->{REMOTE_ADDR},
         $server_addr,
         $env->{HTTP_USER} // "-",
-        _safe($rreq->{action}),
-        _safe("$uri" // "-"),
+        _safe($rreq->{action} // "-"),
+        _safe($uri),
         $args_len.($args_partial ? "p" : ""), $args_s,
         $resp_len.($resp_partial ? "p" : ""), $resp_s,
         $subt, $reqt,
@@ -189,7 +189,7 @@ Plack::Middleware::PeriAHS::LogAccess - Log request
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
